<?php

namespace Pinpoint\SalesRep\Setup;

use Magento\Framework\DB\Ddl\Table;
use Magento\Framework\Setup\InstallSchemaInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;

/**
 * Class InstallSchema
 */
class InstallSchema implements InstallSchemaInterface
{

    /**
     * Install
     * @param \Magento\Framework\Setup\SchemaSetupInterface $installer
     * @param ModuleContextInterface $context
     * @inheritDoc
     * @throws \Zend_Db_Exception
     */
    public function install(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $installer = $setup->startSetup();
        $this->createTableWithForeignKeys($installer);
    }

    /**
     * Create sales rep table
     * @param \Magento\Framework\Setup\SchemaSetupInterface $installer
     * @throws \Zend_Db_Exception
     */
    protected function createTableWithForeignKeys(SchemaSetupInterface $installer)
    {
        $table = $installer->getConnection()->newTable(
            'sales_order_salesrep'
        )
            ->addColumn(
                'entity_id',
                Table::TYPE_INTEGER,
                null,
                ['identity'=> true,'primary' => true, 'nullable'=>false],
                "ENTITY ID"
            )->addColumn(
                'sales_order_entity_id',
                Table::TYPE_INTEGER,
                "10",
                ['unsigned' => true],
                "SALES ORDER ID"
            )->addColumn(
                'user_id',
                Table::TYPE_INTEGER,
                "10",
                ['unsigned' => true],
                "ADMIN USER ID"
            )->addForeignKey( // Add foreign key for table entity
                $installer->getFkName(
                    'sales_order_salesrep', // New table
                    'sales_order_entity_id', // Column in New Table
                    'sales_order', // Reference Table
                    'entity_id' // Column in Reference table
                ),
                'sales_order_entity_id', // New table column
                $installer->getTable('sales_order'), // Reference Table
                'entity_id', // Reference Table Column
                // When the parent is deleted, delete the row with foreign key
                Table::ACTION_CASCADE
            )->addForeignKey( // Add foreign key for table entity
                $installer->getFkName(
                    'sales_order_salesrep', // New table
                    'user_id', // Column in New Table
                    'admin_user', // Reference Table
                    'user_id' // Column in Reference table
                ),
                'user_id', // New table column
                $installer->getTable('admin_user'), // Reference Table
                'user_id', // Reference Table Column
                // When the parent is deleted, delete the row with foreign key
                Table::ACTION_CASCADE
            )->setComment(
                'Sales Representatives Table'
            );

        $installer->getConnection()->createTable($table);
    }
}
